/* Object: buildings
 * Holds information on buildings in-game along with the methods to gather and 
 * store details of the buildings currently in towns.
 * 
 * Properties:
 * bldgs - object. Details of all the buildings available in the game. Organised 
 * by in-game building id.
 * maxPops - object. The maximum possible population of each building. Organised 
 * by building name.
 * 
 * Methods:
 * bldgScan - Scan and store the building levels for the current town. Requires 
 * you be viewing the town map.
 * bldgsDisplay - Display name, current level and maximum population of the 
 * buildings and resource plots in the current town.
 * bldgSearch - Display select box to search all towns for a given building. 
 * Calls <showLvls> on change.
 * showLvls - Display the results of a search.
 */
dt.buildings = {
	townMapAvailable: false,
	/* Method: bldgScan
	 * Scans and stores the building levels for the current town.
	 */
	bldgScan: function () {
		try {
			var msg = "Scanning building levels.";
			dt.logEntry(msg);
			if (window.location == 'https://elgea.illyriad.co.uk/#/Town/Map') {
				var plots = {resource: {1: "", 2: "", 3: "", 4: "", 5: "", 6: "", 7: "", 8: "", 9: "", 10: "", 11: "", 12: "", 13: "", 14: "", 15: "", 16: "", 17: "", 18: "", 19: "", 20: "", 21: "", 22: "", 23: "", 24: "", 25: ""}, internal: {0: "", 1: "", 2: "", 3: "", 4: "", 5: "", 6: "", 7: "", 8: "", 9: "", 10: "", 11: "", 12: "", 13: "", 14: "", 15: "", 16: "", 17: "", 18: "", 19: "", 20: "", 21: "", 22: "", 23: "", 24: "", 25: ""}};
				var srccont = document.querySelector("#townMapOutline");

				var areas = srccont.querySelectorAll("area");
				// Step through each of the areas and extract the plot, name and lvl of the building.
				for (i = 0; i < areas.length; i++) {
					var title = areas[i].getAttribute("title");
					var h = areas[i].getAttribute("href");
					var hparts = h.split('/');
					var t = hparts[2].split('?');
					if (t.length === 1) {
						// Standard building
						var s = title.split('[');
						var bldgName = s[0].trim();
//				bldgName = bldgName.replace("'","");
						var bldgLvl = s[1].replace(']', '').trim();
						if (hparts[3] === "1") {
							plots.resource[hparts[4]] = [bldgName, bldgLvl];
						} else {
							plots.internal[hparts[4]] = [bldgName, bldgLvl];
						}
					} else {
						// Castle
						var s = title.split('[');
						var bldgName = 'Wall';
						var s2 = s[1].split(' ');
						var bldgLvl = s2[1].replace(']', '').trim();
						plots.internal[0] = [bldgName, bldgLvl];
					}
				}
				dt[PlayerId].towns[CurrentTown].plots = plots;
				var key = CurrentTown + ':plots';
				locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].plots));
			}
			var msg = "Building level scan finished.";
			dt.logEntry(msg);
			dt.invent.getTownInventory();
		}
		catch (e) {
			console.log("debug: "+e.message);
			var rubbish = '';
		}
	},
	/* Method: bldgSearch
	 * Display a select box to search all towns for a given building. Calls <showLvls> 
	 * on change.
	 */
	bldgSearch: function () {
		dt.showTool("#bldgSearchHtml");
		dt.removeRows(document.querySelector("#bldgSearchResults"));
	},
	/* Method: bldgsDisplay
	 * Display details of the buildings and resource plots in the town supplied. 
	 * Also calculates and displays the maximum possible population with the 
	 * current buildings at maximum levels.
	 * 
	 * Parameters:
	 * town - integer. The id of the town to display the info for.
	 * dest - string. The id of the location to place the output in.
	 */
	bldgsDisplay: function () {
		dt.showTool("#buildingsHtml");
		var town = CurrentTown;
		var dest = dt_output;
//		dt_input.setAttribute('class', 'nosee');
//		var where = document.querySelector('#' + dest);
		var maxPop = 0;
		var t = dt[PlayerId].towns[town].plots;
		var resTbl = document.querySelector("#tResPlots");
		var bldgTbl = document.querySelector("#tBldgs");
		dt.removeRows(resTbl);
		dt.removeRows(bldgTbl);
//		var resTbl = '<table border="1"><tr><th colspan="3">Resource Plots</th></tr><tr><th>Name</th><th>Lvl</th><th>Max Pop</th></tr>';
		var k = Object.keys(t.resource);
		var tBdy = resTbl.querySelector("tbody");
		for (i = 0; i < k.length; i++) {
			var mp = 0;
			if (this.maxPops.hasOwnProperty(t.resource[k[i]][0])) {
				mp = this.maxPops[t.resource[k[i]][0]];
			}
			if (typeof t.resource[k[i]][0] != 'undefined') {
				var row = tBdy.insertRow(-1);
				var cell = row.insertCell(0);
				cell.textContent = t.resource[k[i]][0];
				cell = row.insertCell(1);
				cell.classList.add("tCenter");
				cell.textContent = t.resource[k[i]][1];
				cell = row.insertCell(2);
				cell.classList.add("tCenter");
				cell.textContent = mp;
//				r = '<tr><td>' + t.resource[k[i]][0] + '</td><td>' + t.resource[k[i]][1] + '</td><td>' + mp + '</tr>';
//				resTbl += r;
				maxPop += mp;
			}
		}
//		resTbl += '</table>';
//		var bldgTbl = '<table border="1"><tr><th colspan="3">Buildings</th></tr><tr><th>Name</th><th>Lvl</th><th>Max Pop</th></tr>';
		var k = Object.keys(t.internal);
		tBdy = bldgTbl.querySelector("tbody");
		for (i = 0; i < k.length; i++) {
			var mp = 0;
			if (this.maxPops.hasOwnProperty(t.internal[k[i]][0])) {
				mp = this.maxPops[t.internal[k[i]][0]];
			}
			var row = tBdy.insertRow(-1);
			var cell = row.insertCell(0);
			cell.textContent = t.internal[k[i]][0];
			cell = row.insertCell(1);
			cell.classList.add("tCenter");
			cell.textContent = t.internal[k[i]][1];
			cell = row.insertCell(2);
			cell.classList.add("tCenter");
			cell.textContent = mp;
//			r = '<tr><td>' + t.internal[k[i]][0] + '</td><td>' + t.internal[k[i]][1] + '</td><td>' + mp + '</tr>';
//			bldgTbl += r;
			maxPop += mp;
//			internal
		}
//		bldgTbl += '</table>';
//		var out = '<table border="1" id="bldgs"><tr><td>' + bldgTbl + '</td><td>' + resTbl + '</td></tr></table><p>Maximum population possible with current buildings:' + maxPop + '</p>';
//		dest.innerHTML = out;
//		dest.setAttribute('class', 'see');
	},
	/* Method: showLvls
	 * Display the results of a building search.
	 */
	showLvls: function () {
		var selBldg = document.querySelector('#bldgSearchInp').value;
		var outTbl = document.querySelector("#bldgSearchResults");
		dt.removeRows(outTbl);
		var bdy = outTbl.querySelector('tbody');
		var twnList = dt[PlayerId].towns.list;
		var r = '';
		for (var twn = 0; twn < twnList.length; twn++) {
			var twnId = twnList[twn];
			var tName = dt[PlayerId].towns[twnId].name;
			var obj = dt[PlayerId].towns[twnId].plots.internal;
			for (var prop in obj) {
				bldgLvl = 0;
				if (obj.hasOwnProperty(prop) && obj[prop][0] === selBldg) {
					bldgLvl = obj[prop][1];
					var row = bdy.insertRow(-1);
					var cell = row.insertCell(0);
					cell.textContent = tName;
					cell = row.insertCell(1);
					cell.classList.add("tCenter");
					cell.textContent = bldgLvl;
				}
			}
			var obj = dt[PlayerId].towns[twnId].plots.resource;
			for (var prop in obj) {
				bldgLvl = 0;
				if (obj.hasOwnProperty(prop) && obj[prop][0] === selBldg) {
					bldgLvl = obj[prop][1];
					var row = bdy.insertRow(-1);
					var cell = row.insertCell(0);
					cell.textContent = tName;
					cell = row.insertCell(1);
					cell.textContent = bldgLvl;
				}
			}
		}
		var dummy = '';
	},
	maxPops: {"Wall": 20, "Storehouse": 37, "Lumberjack": 37, "Clay Pit": 37, "Iron Mine": 37, "Quarry": 37, "Farmyard": 37, "Library": 37, "Barracks": 37, "Marketplace": 37, "Brewery": 40, "Tavern": 1497, "Consulate": 1497, "Carpentry": 1497, "Kiln": 1497, "Foundry": 1497, "Stonemason": 1497, "Flourmill": 16, "Common Ground": 1497, "Paddock": 1497, "Vault": 37, "Mage Tower": 1497, "Fletcher": 1497, "Spearmaker": 1497, "Blacksmith": 1497, "Forge": 1497, "Tannery": 1497, "Saddlemaker": 1497, "Siege Workshop": 1497, "Book Binder": 1497, "Warehouse": 370, "Chancery of Estates": 449, "Runemasters Grounding": 898, "Geomancers\' Retreat": 898, "Scouts\' Lookout": 898, "Spies\' Hideout": 898, "Thieves\' Den": 898, "Saboteurs\' Sanctuary": 898, "Assasins\' Abode": 898, "Spearmens\' Billets": 1796, "Archers\' Field": 1796, "Infantry Quarters": 1796, "Cavalry Parade Ground": 1796, "Architects\' Office": 328, "Foreign Office": 898, "Arctic Warfare College": 0, "Desert Warfare College": 0, "Jungle Warfare College": 0, "Swordsmith": 1497, "Plate Armourer": 1497, "Horse Trainer": 1497, "Skinner\'s Guild": 1497, "Miner\'s Guild": 1497, "Herbalist\'s Guild": 1497, "Merchant\'s Guild": 1510, "Cottage": 4, "Trade Office": 2000, "Spearsmith": 1497, "Bowyer": 1497, "Chain Armourer": 1497, "Leather Armourer": 1497},
};

