/* 
 * Module by Ryan Morr that creates a permanent mutation observer to monitor for
 * the existence of a given element.
 * http://ryanmorr.com/using-mutation-observers-to-watch-for-element-availability/
 */
(function (win) {
	'use strict';

	var listeners = [],
			  doc = win.document,
			  MutationObserver = win.MutationObserver || win.WebKitMutationObserver,
			  observer;

	function ready(selector, fn) {
		// Store the selector and callback to be monitored
		listeners.push({
			selector: selector,
			fn: fn
		});
		if (!observer) {
			// Watch for changes in the document
			observer = new MutationObserver(check);
			observer.observe(doc.documentElement, {
				childList: true,
				subtree: true
			});
		}
		// Check if the element is currently in the DOM
		check();
	}

	function check() {
		// Check the DOM for elements matching a stored selector
		for (var i = 0, len = listeners.length, listener, elements; i < len; i++) {
			listener = listeners[i];
			// Query for elements matching the specified selector
			elements = doc.querySelectorAll(listener.selector);
			for (var j = 0, jLen = elements.length, element; j < jLen; j++) {
				element = elements[j];
				// Make sure the callback isn't invoked with the 
				// same element more than once
				if (!element.ready) {
					element.ready = true;
					// Invoke the callback with the element
					listener.fn.call(element, element);
				}
			}
		}
	}

	// Expose `ready`
	win.ready = ready;

})(this);

// Set up monitoring of the Market/History buttons on the Trade Markets page
ready("#ItemDetail div.sideTab.selected", function (element) {
	if (element.textContent === "History") {
		dt.trade.historySelected = true;
	} else {
		dt.trade.historySelected = false;
	}
	dt.trade.tradeMarkets();
});
// Set up monitoring of the Graph/Data buttons on the Trade Markets page
ready("#graph div.flotr-tabs-group div.flotr-tab.selected", function (element) {
	if (element.textContent === "Data") {
		dt.trade.dataSelected = true;
	} else {
		dt.trade.dataSelected = false;
	}
	dt.trade.tradeMarkets();
});
// Set up monitoring of the #townMapOutline element on the City Map page
ready("#townMapOutline", function (element) {
//window.alert(element);
dt.buildings.bldgScan();
// dt.trade.tradeMarkets();
});

