/* File: inventory.js
 * Defines the methods for collecting and displaying the data about inventories 
 * of items belonging to a player.
 */
dt.invent = {
	/* Method: dispBaseInv
	 * Display the base inventories for all player towns
	 */
	dispBaseInv: function () {
		var towns = dt[PlayerId].towns;
		var townList = towns.list;
		townList.sort();
		var numTowns = towns.numTowns;
		var totals = [0, 0, 0, 0, 0, 0];
		var items = ["name", "Gold", "Wood", "Clay", "Iron", "Stone", "Food"];
		dt.showTool("#baseInvSummHtml");
//		dt.outputArea.innerHTML = dt.townResTbl;
//		var kids = dt.outputArea.children;

		var tbl = document.getElementById('townres');
		dt.removeRows(tbl);
		var body = tbl.getElementsByTagName('tbody').item(0);
		// Step through all the towns
		for (var i = 0; i < numTowns; i++) {
			// Process the current town
			var row = body.insertRow(-1);
			var row2 = body.insertRow(-1);
			var cell = row.insertCell(0);
			var cell2 = row2.insertCell(0);
			var thisTown = towns[townList[i]];
			var inv = thisTown.inv;
			// Create a check for res and each of the base resources existing.
			var res = inv.res;
			cell.innerHTML = thisTown.name;
			cell2.textContent = 'Time left:';
			for (var j = 1; j < items.length; j++) {
				cell = row.insertCell(j);
				cell2 = row2.insertCell(j);
				var pName = items[j];
				if (res.hasOwnProperty(pName)) {
					if (parseFloat(res[pName].rate) < 0) {
						cell.setAttribute('class', 'red');
						cell2.setAttribute('class', 'red');
					}
					if (parseFloat(res[pName].rate) > 0) {
						cell2.setAttribute('class', 'greenT');
					}
					if(res[pName].held == dt[PlayerId].towns[CurrentTown].inv.maxStore){
						cell.setAttribute('class','blue');
					}
					cell.innerHTML = dt.numberFormat(res[pName].held);
					totals[j - 1] = totals[j - 1] + parseInt(res[pName].held);
					if (parseFloat(res[pName].rate) < 0) {
						var secs = res[pName].held / parseFloat(res[pName].rate);
					} else {
						var diff = dt[PlayerId].towns[CurrentTown].inv.maxStore - res[pName].held;
						var secs = diff / parseFloat(res[pName].rate);
					}
//					cell2.innerHTML = dt.numberFormat2(hrs);
					cell2.innerHTML = dt.secondsToString2(secs);
					if (j === 1 && parseFloat(res[pName].rate) >= 0) {
						cell2.innerHTML = "-";
					}
				} else {
					cell.innerHTML = "?";
					cell.innerHTML = "-";
				}
			}
		}
//		dt.addElement2(tbl, 'tfoot', ['id'], ['totals']);
//		var tfoot = document.getElementById('totals');
		var tfoot = tbl.querySelector("tfoot");
		var rowText = '<td>Totals</td>';
//		var cell = tfoot.insertCell(0);
//		cell.innerHTML = 'Totals';
		for (var j = 0; j < 6; j++) {
//			cell = tfoot.insertCell(j);
//			cell.innerHTML = dt.numberFormat(totals[j]);
			rowText = rowText + '<td>' + dt.numberFormat(totals[j]) + '</td>';
		}
		tfoot.innerHTML = rowText;
//		dt.outputArea.setAttribute('class', 'see');
	},
	/* Method: dispSubInvs
	 * Build and display the sub-inventory tool
	 */
	dispSubInvs: function () {
		dt.showTool("#subInvHtml");
		// Get the outer table
		var toolTable = document.querySelector('#subInvToolTable');
		// Get the tbody that the town & hub links are held in
		var linkBody = document.querySelector("#subInvToolTable td.townCol tbody");
		// Populate the list of towns & hubs
		var twnArea = toolTable.querySelector('.townCol');
		var twnList = twnArea.querySelector('tbody');
		// <tr><td height="29" class="titleCell">Towns</td></tr>
		linkBody.innerHTML = '';
		var tRow = dt.addElement2(linkBody, 'tr');
		var tCell = dt.addElement2(tRow, 'td', ['class', 'height'], ['titleCell', '29']);
		tCell.textContent = "Location";
		tRow = dt.addElement2(linkBody, 'tr');
		tCell = dt.addElement2(tRow, 'td', ['onclick', 'class', 'data-where', 'data-id'], ["dt.invent.invSwitch('all','-1')", 'dthover', 'all', '-1']);
		tCell.textContent = "Everywhere";
		tRow = dt.addElement2(linkBody, 'tr');
		tCell = dt.addElement2(tRow, 'td', ['class', 'height'], ['titleCell', '29']);
		tCell.textContent = "Towns";

		for (var i = 0; i < dt[PlayerId].towns.numTowns; i++) {
			var tRow = dt.addElement2(linkBody, 'tr');
			var tCell = dt.addElement2(tRow, 'td', ['data-id', 'class', 'data-where'], [dt[PlayerId].towns.list[i], 'dthover', 'towns']);
			var thisTwn = dt[PlayerId].towns.list[i];
			tCell.innerHTML = dt[PlayerId].towns[thisTwn].name;
			tCell.setAttribute('onclick', 'dt.invent.invSwitch("town",' + thisTwn + ')');
		}
		var tRow = dt.addElement2(linkBody, 'tr');
		var tCell = dt.addElement2(tRow, 'td', ['class', 'height'], ['titleCell', '29']);
		tCell.innerHTML = 'Hubs';
		for (var i = 0; i < dt[PlayerId].hubs.numHubs; i++) {
			var tRow = dt.addElement2(linkBody, 'tr');
			var tCell = dt.addElement2(tRow, 'td', ['data-id', 'class', 'data-where'], [dt[PlayerId].hubs.list[i], 'dthover', 'hubs']);
			var thisHub = dt[PlayerId].hubs.list[i];
			tCell.innerHTML = dt[PlayerId].hubs[thisHub].name;
			tCell.setAttribute('onclick', 'dt.invent.invSwitch("hub",' + thisHub + ')');
		}
		// Set the current town as the active location
		dt.invent.invSwitch('town', CurrentTown);

		var invArea = document.getElementById('invCol');
	},
	/* Method: invSwitch
	 * Handle a change of either town or sub-inventory
	 * 
	 * Parameters:
	 * part - what is being changed. One of either:
	 *				tab (what sub-inventory),
	 *				town (a town has been selected),
	 *				hub (a hub has been selected) or
	 *				all (inventories from everywhere are wanted).
	 *	new_tab - the data-id of the particular item that is being changed.
	 */
	invSwitch: function (part, new_tab) {
		var toolDiv = document.querySelector('#subInvHtml');
		var tc = toolDiv.querySelector('.townCol');
		// 
		if (part === 'tab') {
			// First remove the active setting on the current inventory
			document.querySelector('#invAreaSel td.dtActive').classList.remove('dtActive');
			var rubbish = '';
			// Now get the new inventory to mark as active
			// toolDiv.querySelector('[data-id="'+new_tab+'"]').classList.add("dtActive");
			var newSub = document.querySelector('#invAreaSel td[data-id="' + new_tab + '"]');
			newSub.classList.add('dtActive');

//		document.getElementById(new_tab).classList.add("dtActive");
			var townCol = toolDiv.querySelector('.townCol');
			var town = townCol.querySelector('.dtActive').getAttribute('id');
			var where = townCol.querySelector('.dtActive').getAttribute('data');
			var invArea = new_tab;
		}
		if (part === 'town') {
			// Set the active town
//		var activTwn = toolDiv.querySelector('.townCol td.dtActive');
			var townCol = document.querySelector('#subInvHtml .townCol');
			var twns = townCol.getElementsByTagName('td');
			for (var i = 1; i < twns.length; i++) {
				twns.item(i).classList.remove("dtActive");
			}
			// Set the selected town to active
			var activTwn = townCol.querySelector('#' + part);
//		document.querySelector("[data-id='"+new_tab+"']")
			toolDiv.querySelector('[data-id="' + new_tab + '"]').classList.add("dtActive");
			var source = new_tab;
			var invSel = document.getElementById('invAreaSel');
			var invArea = document.querySelector('#invAreaSel .dtActive').getAttribute('data-id');
//		var invArea = invSel.getElementsByClassName('dtActive').item(0).getAttribute('id');
			var town = new_tab;
			var where = 'towns';
			//invAreaSel
		}
		if (part === 'hub') {
			// Set the active hub
			var townCol = document.querySelector('#subInvHtml .townCol');
			var twns = townCol.getElementsByTagName('td');
			for (var i = 1; i < twns.length; i++) {
				twns.item(i).classList.remove("dtActive");
			}
			toolDiv.querySelector('[data-id="' + new_tab + '"]').classList.add("dtActive");
//		document.getElementById(new_tab).classList.add("dtActive");
			var source = new_tab;
			var invSel = document.getElementById('invAreaSel');
			var invArea = invSel.getElementsByClassName('dtActive').item(0).getAttribute('id');
			var town = new_tab;
			var where = 'hubs';
		}
		if (part === 'all') {
			// Set the active hub
			var townCol = toolDiv.querySelector('.townCol');
			var twns = townCol.getElementsByTagName('td');
			for (var i = 1; i < twns.length; i++) {
				twns.item(i).classList.remove("dtActive");
			}
//		document.getElementById(new_tab).classList.add("dtActive");
			toolDiv.querySelector('[data-where="all"]').classList.add("dtActive");
			var source = new_tab;
			var invSel = document.getElementById('invAreaSel');
			var invArea = invSel.getElementsByClassName('dtActive').item(0).getAttribute('id');
			var town = new_tab;
			var where = 'all';
		}
		var rubbish = '';
//	dt.invent.dispSubInv(where, town, invArea);
		dt.invent.dispSubInv();
	},
	/* Method: dispSubInv
	 * Display selected sub-inventory for the chosen town.
	 */
//dispSubInv: function (where, viewTown, subId) {
	dispSubInv: function () {
		// Get the active location
		var loc = document.querySelector("#subInvToolTable td.townCol tbody td.dtActive");
		var where = loc.dataset.where;
		var viewTown = loc.dataset.id;
		var subId = document.querySelector('#invAreaSel td.dtActive').getAttribute('data-id');
		if (where == 'all') {
			dt.invent.buildInvTotals();
			var res = dt.invTot[subId];
		} else {
			var res = dt.sortObject(dt[PlayerId][where][viewTown].inv[subId]);
		}
		var invArea = document.getElementById('subInvDispArea');
		invArea.innerHTML = '';
		var keys = Object.keys(res);
		for (var i = 0; i < keys.length; i++) {
			if (keys[i] !== '') {
				if (parseFloat(res[keys[i]].rate) < 0) {
					if (where == "all") {
						var spn = '<span class="name ' + res[keys[i]].classes + '" data="' + res[keys[i]].id + '"></span><br><span width="100%" text-align="center" class ="red">' + dt.numberFormat2(res[keys[i]].held) + '</span>';
					} else {
						var spn = '<span class="name ' + res[keys[i]].classes + '" data="' + res[keys[i]].id + '"></span><br><span width="100%" text-align="center" class ="red">' + dt.numberFormat(res[keys[i]].held) + '</span>';
					}
				} else {
					if (where == "all") {
						var spn = '<span class="name ' + res[keys[i]].classes + '" data="' + res[keys[i]].id + '"></span><br><span width="100%" text-align="center">' + dt.numberFormat2(res[keys[i]].held) + '</span>';
					} else {
						var spn = '<span class="name ' + res[keys[i]].classes + '" data="' + res[keys[i]].id + '"></span><br><span width="100%" text-align="center">' + dt.numberFormat(res[keys[i]].held) + '</span>';
					}
				}
				var newNode = document.createElement('div');
				newNode.setAttribute('title', keys[i]);
				newNode.classList.add("subInvItem");
				newNode.innerHTML = spn;
				invArea.appendChild(newNode);
			}
		}
		dt.adjustTool("#subInvHtml");
	},
	/* Method: buildInvTotals
	 * Build a total of the holdings of an item across all locations
	 * 
	 */
	buildInvTotals: function () {
		dt.invTot = {"res": {}, "mounts": {}, "weapons": {}, "armour": {}, "anatomies": {}, "minerals": {}, "herbs": {}, "exotic": {}};
		var subs = Object.keys(dt.invTot);
		// Step through the locations
		var locs = dt[PlayerId].towns.list;
		for (i = 0; i < locs.length; i++) {
			var thisInv = dt[PlayerId].towns[locs[i]].inv;
			for (s = 0; s < subs.length; s++) {
				var thisSub = thisInv[subs[s]];
				var k = Object.keys(thisSub);
				for (j = 0; j < k.length; j++) {
					if (dt.invTot[subs[s]].hasOwnProperty(k[j])) {

						dt.invTot[subs[s]][k[j]].held = parseInt(dt.invTot[subs[s]][k[j]].held) + parseInt(thisSub[k[j]].held);
					} else {
						dt.invTot[subs[s]][k[j]] = thisSub[k[j]];
					}
					var rubbish = '';
				}
			}
			var rubbish = '';
		}
		var rubbish = '';
	},
	/* Function: getHubInv
	 * Get details of items held from the currently displayed sub-inventory Hub Inventory page. Store the results in the relevant inv property for the current hub and update the object in local storage.
	 */
	getHubInv: function (params) {
//	var nameSwap = {'i=3|1': 'Horse', 'i=3|2': 'Livestock', 'i=3|3': 'Sword', 'i=3|4': 'Bow', 'i=3|5': 'Spear', 'i=3|6': 'Saddle', 'i=3|7': 'Book', 'i=3|8': 'Leather Armour', 'i=3|9': 'Chainmail', 'i=3|10': 'Plate Armour', 'i=3|11': 'Siege Block', 'i=3|12': 'Beer'};
		// Check if the bottom inventory section is available otherwise exit the function.
		if (document.getElementById('inventoryLinks')) {
			var area =
					  ['res', 'weapons', 'armour', 'anatomies', 'minerals', 'herbs', 'exotic', 'mounts'];
			var headLink = document.getElementById('inventoryLinks').getElementsByClassName('selected').item(0).getAttribute('data-id');
			var t = document.getElementById('inventoryLinks').getElementsByClassName('selected').item(0).getAttribute('href');
			var bits = t.split('?');
//			var params = bits[1].split('&');
//			var thisHub = params[0].split('=')[1];
			var thisHub = params[0][1];
//			var subInvId = params[1].split('=')[1];
			var subInvId = params[1][1];
			dt[PlayerId].hubs[thisHub].inv[area[subInvId]] = {};
			var invTbl = document.querySelector("table.generic.oddeven.middle");
			var rubbish = '';
			var thisTbl = invTbl;
			// Get each of the rows in this table
			var rows = thisTbl.getElementsByTagName('tr');
			if (rows.length > 2) {
				// check the first td in the first item row. If it has a <span> child then go ahead.
				// html body div div.content table.generic tbody tr td#contentTD div.largeBorder div.scrollContent div#MainContentDiv div.info table.generic.oddeven.middle tbody tr td
				// html body div div.content table.generic tbody tr td#contentTD div.largeBorder div.scrollContent div#MainContentDiv div.info table.generic.oddeven.middle tbody tr td span.name.resIcon.ico-wood
				if (rows.item(1).querySelector(" td span")) {
					for (var j = 1; j < (rows.length - 1); j++) {
						// Get the cells in this row
						var cells = rows.item(j).getElementsByTagName('td');
						if (cells.length !== 1) {
							// Step through the cells
							for (var c = 0; c < cells.length; c++) {
								switch (c) {
									case 0:
										var s = cells.item(0).getElementsByTagName('span').item(0);
										var itemId = s.getAttribute("data");
										var classes = s.getAttribute("class");
										classes = classes.replace('name', '');
										classes.trim();
										break;
									case 1:
										var resName = cells.item(1).textContent;
										break;
									case 2:
										var holdings = cells.item(2).innerHTML;
										holdings = dt.replaceAll(holdings, ',', '');
//								holdings = holdings.replace(',', '');
										break;
								}
							}
						} else {
							var nothinghere = true;
						}
						if (nothinghere === true) {
							dt[PlayerId].hubs[thisHub].inv[area[subInvId]] = {};
						} else {
							var target = dt[PlayerId].hubs[thisHub].inv[area[subInvId]];
							Object.defineProperty(dt[PlayerId].hubs[thisHub].inv[area[subInvId]], resName, {value: '', writable: true, enumerable: true, configurable: true});
							dt[PlayerId].hubs[thisHub].inv[area[subInvId]][resName] = {"id": itemId, "held": holdings, "rate": 0, "classes": classes};
						}
					}
				}
			}
			var key = PlayerId + ':hubs';
			var rubbish = '';
			locStorage.setItem(key, JSON.stringify(dt[PlayerId].hubs));
			dt[PlayerId].hubs = JSON.parse(locStorage.getItem(key));
		}
	},
	/* Function: searchInv
	 * Search the inventories of all towns to find how many of an item are held in each town.
	 */
	invSearch: function () {
		dt.showTool("#invSearchHtml");
		// Get the names of all possible items
		var itemNames = [];
		// Get the item to be searched for.
//	document.getElementById('dt_input').innerHTML = dt.searchInp;
		var dt_search = document.getElementById('dt_searchInp');
//	document.getElementById('dt_input').setAttribute('class', 'see');
		dt_search.setAttribute('class', 'see');
	},
	showResult: function (str) {
		var dt_search = document.getElementById('dt_searchInp');
		var dt_searchSuggestions = document.getElementById("dt_livesearch");
		dt_searchSuggestions.classList.remove('nosee');
		dt_searchSuggestions.classList.add('see');
		if (str.length < 2) {
			document.getElementById("dt_livesearch").innerHTML = "";
			document.getElementById("dt_livesearch").style.border = "0px";
			return;
		}
		str = str.toLowerCase();
		var itemNames = [];
		var keys = Object.keys(cp);
		dt_searchSuggestions.innerHTML = '';
		for (var i = 0; i < keys.length; i++) {
			var name = cp[keys[i]].n;
			var lowerName = name.toLowerCase();
			if (lowerName.indexOf(str) !== -1) {
				var t = name.split(' ');
				var t2 = t.join('_');
				var t3 = '<span onclick = dt.invent.selectThis("' + t2 + '"' + ',' + keys[i] + ') cId="' + keys[i] + '">' + name + '</span><br>';
				itemNames.push(t);
				dt_searchSuggestions.innerHTML += t3;
				var dummy = '';
			}
		}
		if (itemNames.length > 0) {
			dt_search.innerHTML = itemNames;
			dt_searchSuggestions.style.border = "1px solid #A5ACB2";
		} else {
			dt_searchSuggestions.innerHTML = '';
			dt_searchSuggestions.style.border = "none";
		}
	},
	selectThis: function (name, cId) {
		dt.searchResults = {};
		document.querySelector('#invSearchResHtml').classList.remove('nosee');
		document.querySelector('#invSearchResHtml').classList.add('see');
		document.querySelector('#invSearchResHtml h2').textContent = 'Search Results for - ' + name;
		// Get the results table
		var theTable = document.querySelector('#dt_searchResults tbody');
		dt.removeRows(theTable.parentNode);
		document.querySelector('#usedin').innerHTML = '';
		// Replace any underscores in name with spaces
		var t = name.split('_');
		var name = t.join(' ');
		var totalHeld = 0;
		document.getElementById('dt_searchInp').value = name;
		// Clear and hide the suggestions.
//	document.getElementById("dt_livesearch").innerHTML = "";
		document.getElementById("dt_livesearch").className = "nosee";
		// Loop through all the towns
		var twnList = dt[PlayerId].towns.list;
		for (var twn = 0; twn < twnList.length; twn++) {
			var twnId = twnList[twn];
			// Set the results for this town to 0
			dt.searchResults[twnId] = 0;
			// Get the properties of the inv object for this town
			var props = Object.getOwnPropertyNames(dt[PlayerId].towns[twnId].inv);
			// Step through these properties
			for (var propId = 0; propId < props.length; propId++) {
				// Check if this sub-inventory has a property matching the name we are looking for
				if (dt[PlayerId].towns[twnId].inv[props[propId]].hasOwnProperty(name)) {
					// There is a matching item so get the qty held
					dt.searchResults[twnId] = dt[PlayerId].towns[twnId].inv[props[propId]][name].held;
					if (parseFloat(dt[PlayerId].towns[twnId].inv[props[propId]][name].rate) < 0) {
						var redLine = true;
					} else {
						var redLine = false;
					}
				}
			}
			// Add a row to the results table
			var row = theTable.insertRow(-1);
			var cell = row.insertCell(0);
			cell.innerHTML = dt[PlayerId].towns[twnId].name;
			cell = row.insertCell(1);
			if (redLine === true) {
				cell.setAttribute('class', 'red');
			}
			cell.innerHTML = dt.numberFormat(dt.searchResults[twnId]);
			totalHeld = totalHeld + parseInt(dt.searchResults[twnId]);
		}
		// Loop through the hubs
		if (dt[PlayerId].hubs.hasOwnProperty('list')) {
			var twnList = dt[PlayerId].hubs.list;
			for (var twn = 0; twn < twnList.length; twn++) {
				var twnId = twnList[twn];
				// Set the results for this town to 0
				dt.searchResults[twnId] = 0;
				// Get the properties of the inv object for this town
				var props = Object.getOwnPropertyNames(dt[PlayerId].hubs[twnId].inv);
				// Step through these properties
				for (var propId = 0; propId < props.length; propId++) {
					// Check if this sub-inventory has a property matching the name we are looking for
					if (dt[PlayerId].hubs[twnId].inv[props[propId]].hasOwnProperty(name)) {
						// There is a matching item so get the qty held
						dt.searchResults[twnId] = dt[PlayerId].hubs[twnId].inv[props[propId]][name].held;
					}
				}
				// Add a row to the results table
				var row = theTable.insertRow(-1);
				var cell = row.insertCell(0);
				cell.innerHTML = dt[PlayerId].hubs[twnId].name;
				cell = row.insertCell(1);
				cell.innerHTML = dt.numberFormat(dt.searchResults[twnId]);
//			if (dt[PlayerId].hubs[twnId].name = 'All Hubs') {
				if (twnId == 0) {
					totalHeld = totalHeld + parseInt(dt.searchResults[twnId]);
				}
			}
		}
		// Add a row for the total held
		var row = theTable.insertRow(-1);
		var cell = row.insertCell(0);
		cell.innerHTML = 'Total held';
		cell = row.insertCell(1);
		cell.innerHTML = dt.numberFormat(totalHeld);

		var usedIn = [];
		// Get details of the items this is used in (if any)
		itemId = 'c=' + cId;
		if (dt.cpi.hasOwnProperty(cId)) {
			itemId = dt.cpi[cId];
		}

		// 2. Step through each of the recipes
		var count = 0;
		for (var k in dt.cRecipes)
			++count;
		var keys = Object.keys(dt.cRecipes);

		for (var item = 0; item < keys.length; item++) {
			// Check to see if the item is in this recipe
			for (var subitem = 0; subitem < dt.cRecipes[keys[item]].recipe.length; subitem++) {
				if (dt.cRecipes[keys[item]].recipe[subitem][1] == itemId) {
					usedIn.push(keys[item]);
				}
			}
		}
		if (usedIn.length > 0) {
			var out = document.getElementById('usedin');
			var usedhdr = dt.addElement2(out, 'h3', [], []);
			usedhdr.textContent = 'Used In:';
			for (item in usedIn) {
				if (dt.cpi.hasOwnProperty(usedIn[item])) {
					dataVal = dt.cpi[item];
				} else {
					dataVal = 'c=' + usedIn[item];
				}
				dt.addElement2(out, 'span', ['class', 'title', 'data'], ['name ' + dt.cItems[usedIn[item]].classes, dt.cItems[usedIn[item]].name, dataVal])
			}
		}
		dt.adjustTool('#invSearchHtml');
	},
	/* Method: getTownInventory
	 * Scan the current page for any available inventory information.
	 * 
	 * Calls:
	 * <getTopRes>, <getAdvRes>, <getBottomInv>
	 */
	getTownInventory: function () {
//		var msg = "Scanning town inventory.";
//		dt.logEntry(msg);
		dt.invent.getTopRes();
		dt.invent.getAdvRes();
		dt.invent.getBottomInv();
//		var msg = "Town inventory scan finished.";
//		dt.logEntry(msg);
	},
	/* Method: getTopRes
	 * Get the resource levels and increase rates for all the resources in the top bar and store the results in the inv object for the current town and update the object in local storage.
	 * 
	 * Calls:
	 * <scanTbl>
	 */
	getTopRes: function () {
		try {
//			var msg = "Scanning base resources.";
//			dt.logEntry(msg);
			console.log("Base inv scan...");
			var tbl = document.getElementById("tbRes");
			var row = tbl.getElementsByTagName("tr").item(0);
			var cells = row.getElementsByTagName("td");
			dt[PlayerId].towns[CurrentTown].inv.maxStore = maxStorage;
			dt.invent.scanTbl(cells, dt[PlayerId].towns[CurrentTown].inv.res);
			// Store the inv object
			var key = CurrentTown + ':inv';
			locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].inv));
			var msg = "Base resource scan done.";
			dt.logEntry(msg);
		}
		catch (e) {
//			console.log("error in call to inventory gathering at the end of hashChanged...");
			console.log("debug: " + e.message);
			var rubbish = '';
		}
	},
	/* Function: getAdvRes
	 * Get the resource levels and increase rates for all the resources in the adv res bar. Store the results in the inv object for the current town and update the object in local storage.
	 * 
	 * Calls:
	 * <scanTbl>
	 */
	getAdvRes: function () {
		try {
//			var msg = "Scanning adv resources.";
//			dt.logEntry(msg);
			console.log("Adv res scan...");
			var tbl = document.getElementById("advRes");
			var row = tbl.getElementsByTagName("tr").item(0);
			var cells = row.getElementsByTagName("td");
			dt.invent.scanTbl(cells, dt[PlayerId].towns[CurrentTown].inv.res);
			// Store the inv object
			var key = CurrentTown + ':inv';
			locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].inv));
			var msg = "Adv res scan finished.";
			dt.logEntry(msg);
		}
		catch (e) {
//			console.log("error in call to inventory gathering at the end of hashChanged...");
			console.log("debug: " + e.message);
			var rubbish = '';
		}
	},
	/* Function: getBottomInv
	 * Get details of items held from the currently displayed sub-inventory at the bottom of the inventory page. Store the results in the relevant inv property for the current town and update the object in local storage.
	 */
	getBottomInv: function () {
		try {
			if (document.querySelector('#subInventory .info span')) {
//				var msg = "Scanning bottom inventory.";
//				dt.logEntry(msg);
				console.log("Bottom inv scan...");
				var nameSwap = {'i=3|1': 'Horse', 'i=3|2': 'Livestock', 'i=3|3': 'Sword', 'i=3|4': 'Bow', 'i=3|5': 'Spear', 'i=3|6': 'Saddle', 'i=3|7': 'Book', 'i=3|8': 'Leather Armour', 'i=3|9': 'Chainmail', 'i=3|10': 'Plate Armour', 'i=3|11': 'Siege Block', 'i=3|12': 'Beer'};

				var area = ['res', 'weapons', 'armour', 'anatomies', 'minerals', 'herbs', 'exotic', 'mounts'];
				try {
					var headLink = document.getElementById('inventoryLinks').getElementsByClassName('selected')[0].getAttribute('data-id');
					var subInv = document.getElementById('subInventory');
					var inf = subInv.querySelector('.info');
					var tbls = inf.querySelectorAll('table');
					if (document.querySelector('.info > table').querySelectorAll('tr').length < 2) {
						// No items so clear the sub-inv and store it
						dt[PlayerId].towns[CurrentTown].inv[area[headLink]] = {};
						var key = CurrentTown + ':inv';
						locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].inv));
						dt[PlayerId].towns[CurrentTown].inv = JSON.parse(locStorage.getItem(key));
					} else {
						// There are items. Ignore the Resources tab but process the others
						if (headLink > 0) {
							dt[PlayerId].towns[CurrentTown].inv[area[headLink]] = {};
							// Get all of the rows in this sub-inv
							var rows = document.querySelector('.info > table').querySelectorAll('tr');
							// Get all of the rows in this sub-inv
							for (var j = 1; j < rows.length; j++) {
								// Get the cells in this row
								var cells = rows.item(j).getElementsByTagName('td');
								// Process this row. Interested in the first and third cells. Only 
								// process if the first cell contains a span
//				if(cells[0].querySelector('span')){
								var s = cells[0].querySelector('span');
								var resName = s.getAttribute("title");
								var itemId = s.getAttribute("data");
								var classes = s.getAttribute("class");
								classes = classes.replace('name', '');
								classes.trim();
								var holdings = cells[2].innerHTML;
								holdings = holdings.replace(',', '');
								// Update the dom sub-inv
								var target = dt[PlayerId].towns[CurrentTown].inv[area[headLink]];
								Object.defineProperty(dt[PlayerId].towns[CurrentTown].inv[area[headLink]], resName, {value: '', writable: true, enumerable: true, configurable: true});
								dt[PlayerId].towns[CurrentTown].inv[area[headLink]][resName] = {"id": itemId, "held": holdings, "rate": 0, "classes": classes};
							}
							var msg = "Scanning " + area[headLink] + " sub-inventory finished.";
							dt.logEntry(msg);
						}
						// Store the updated inventory
						var key = CurrentTown + ':inv';
						locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].inv));
						dt[PlayerId].towns[CurrentTown].inv = JSON.parse(locStorage.getItem(key));
					}
				}
				catch (e) {
					var rubbish = '';
				}
//				var msg = "Bottom res scan finished.";
//				dt.logEntry(msg);
			}
		}
		catch (e) {
//			console.log("error in call to inventory gathering at the end of hashChanged...");
			console.log("debug: " + e.message);
			var rubbish = '';
		}
	},
	/* Method: scanTbl
	 * 
	 */
	scanTbl: function (cells, target) {
		var nameSwap = {'i=3|1': 'Horse', 'i=3|2': 'Livestock', 'i=3|3': 'Sword', 'i=3|4': 'Bow', 'i=3|5': 'Spear', 'i=3|6': 'Saddle', 'i=3|7': 'Book', 'i=3|8': 'Leather Armour', 'i=3|9': 'Chainmail', 'i=3|10': 'Plate Armour', 'i=3|11': 'Siege Block', 'i=3|12': 'Beer'};
		for (var i = 0; i < cells.length; i++) {
			var thisCell = cells.item(i);
			if (thisCell.classList.contains("resTxt")) {
				// Get the holding and increase rate for this resource.
				var holdings = thisCell.getAttribute("data");
				var increase = thisCell.getAttribute("inc");
			}
			if (thisCell.classList.contains("resIco")) {
				// Get the name of this resource.
				var resName = thisCell.children.item(0).getAttribute("title");
				var itemId = thisCell.children.item(0).getAttribute("data");
				var classes = thisCell.children.item(0).getAttribute("class");
				if (nameSwap.hasOwnProperty(itemId)) {
					resName = nameSwap[itemId];
				}
				classes = classes.replace('name', '');
				classes.trim();
			}
			if (i % 2 !== 0) {
				Object.defineProperty(target, resName, {value: '', writable: true, enumerable: true, configurable: true});
				dt[PlayerId].towns[CurrentTown].inv.res[resName] = {"id": itemId, "held": holdings, "rate": increase, "classes": classes};
			}
		}
	},
//	tradeMarkets: function () {
//		var selArea = document.getElementById("ItemDetail").getElementsByClassName('sideTab selected').item(0);
//		if (selArea !== null) {
//			if (selArea.textContent === 'History') {
//				// html body div div.content table.generic tbody tr td#contentTD div.largeBorder div.scrollContent div#MainContentDiv div div#ItemDetail div div.subLinks a.selected
//				var dataType = document.getElementById("ItemDetail").querySelector('div.subLinks a.selected').textContent;
////				var dataType = document.getElementsByClassName('subLinks a.selected').item(0);
//				if (dataType !== null) {
//					var displayType = document.getElementById("ItemDetail").getElementsByClassName('flotr-tab selected').item(0).textContent;
//					if (displayType === 'Data') {
//						if (!document.getElementById('extDL')) {
//							var parent = document.querySelector('div.flotr-datagrid-toolbar');
//							// <button class="flotr-datagrid-toolbar-button" type="button">Download CSV</button>
//							var newBut = dt.addElement(parent, 'button', ['class', 'type', 'onclick', 'id'], ['dt-added-button', 'button', 'dt.invent.extDownload()', 'extDL']);
//							newBut.textContent = "Ext Download";
//							var rubbish4 = '';
//						}
//					}
//					var rubbish3 = '';
//				}
//				var rubbish2 = '';
//			}
//		}
//		var rubbish1 = '';
//	},
};