/* File: military.js
 * Defines the methods for collecting and displaying the data about military 
 * units belonging to a player.
 */

dt.military = {
	/* Object: mil
	 * Holds all data for mil units and commanders in a town.
	 * 
	 * Properties:
	 * commanders - object. Holds details of the commanders based in this town.
	 * units - object. Details of the units currently available or beinf built in this town.
	 * armies - object. Details of any armies currently in this town.
	 * summary - ?
	 */
	mil: function (commanders, units, armies, summary) {
		this.commanders = commanders;
		this.units = units;
		this.armies = armies;
		this.summary = summary
	},
	/* Object: commander
	 * Holds all data for a mil commander.
	 * 
	 * Properties:
	 * name - string. The name of this commander.
	 * lvl - integer. The level of this commander.
	 * xp - integer. The current experience of this commander.
	 * self - object. Details of the self bonus levels for this commander.
	 * div - object. Details of the division bonus levels for this commander.
	 * uType - string. The type of unit for this commander (Knight, Charioteer etc)
	 */
	commander: function (name, lvl, xp, self, div, uType) {
		this.name = name;
		this.lvl = lvl;
		this.self = self; // object
		this.div = div; // object
		this.uType = uType;
	},
	cmdSelf: function (atk, spDef, rgDef, infFef, cavDef, cbtSurv, health, heal, escAssas) {
		this.atk = atk;
		this.spDef = spDef;
		this.rgDef = rgDef;
		this.infDef = infDef;
		this.cavDef = cavDef;
		this.cbtSurv = cbtSurv;
		this.health = health;
		this.heal = heal;
		this.escAssas = escAssas;
	},
	cmdDiv: function (spAtk, rgAtk, infAtk, cavAtk, spDef, rgDef, infDef, cavDef, move, carry, magic) {
		this.spAtk = spAtk;
		this.rgAtk = rgAtk;
		this.infAtk = infAtk;
		this.cavAtk = cavAtk;
		this.spDef = spDef;
		this.rgDef = rgDef;
		this.infDef = infDef;
		this.cavDef = cavDef;
		this.move = move;
		this.carry = carry;
		this.magic = magic
	},
	/* Method: addOccupyMax
	 * Adds a button to each of the army feldsets on the Military Orders page. 
	 * This button will call setOccupyMax when clicked.
	 */
	addOccupyMax: function () {
		var fsets = document.getElementsByName('holdFieldset');
		for (var i = 0; i < fsets.length; i++) {
			var cell = fsets.item(i).querySelector('td');
			if (!cell.querySelector(".maxb")) {
				dt.addElement2(cell, 'input', ['onclick', 'class', 'value', 'type'], ['dt.military.setOccupyMax(' + i + ')', 'maxb', 'Max', 'button']);
			}
		}
	},
	/* Method: setOccupyMax
	 * Sets the occupy time to the maximum for the current army.
	 * 
	 * Parameter:
	 * fset - integer. The index in the NodeList of fieldsets for the current army.
	 */
	setOccupyMax: function (fset) {
		var fsets = document.getElementsByName('holdFieldset');
		var cell = fsets.item(fset).querySelector('td');
		var days = cell.querySelector('select[name="holdDays"');
		var hours = cell.querySelector('select[name="holdHours"');
		var mins = cell.querySelector('select[name="holdMins"');
		mins.options.selectedIndex = 59;
		hours.options.selectedIndex = 23;
		days.options.selectedIndex = 14;
	},
	/* Function: dispTroopSum
	 * Build and display the table holding the town(s) troop summary.
	 */
	dispTroopSum: function () {
		var towns = dt[PlayerId].towns;
		var townList = towns.list;
		var tots = {spear: {t1: {pool: 0, build: 0}, t2: {pool: 0, build: 0}}, inf: {t1: {pool: 0, build: 0}, t2: {pool: 0, build: 0}}, range: {t1: {pool: 0, build: 0}, t2: {pool: 0, build: 0}}, cav: {t1: {pool: 0, build: 0}, t2: {pool: 0, build: 0}}, siege: {t1: {pool: 0, build: 0}, t2: {pool: 0, build: 0}}};
		var defScores = {};
		var tpNums = {};
		townList.sort();
		var numTowns = towns.numTowns;
		// Build the objects for the tables
		for (var i = 0; i < numTowns; i++) {
			defScores[townList[i]] = towns[townList[i]].mil.summary;
			tpNums[townList[i]] = towns[townList[i]].mil.units;
		}
//		var tpSumPopup = $(function () {
//			$("#troopSummHtml").dialog();
//		});

		var tbl1 = document.getElementById('milSummTbl');
		var tbl2 = document.getElementById('defSummTbl');
		var body1 = tbl1.getElementsByTagName('tbody').item(0);
		dt.removeRows(tbl1);
		dt.removeRows(tbl2);

		for (var i = 0; i < numTowns; i++) {
			var body2 = tbl2.getElementsByTagName('tbody').item(0);
			var row1 = body1.insertRow(-1);
			var cell1 = row1.insertCell(0);
			var row2 = body2.insertRow(-1);
			var cell2 = row2.insertCell(0);
			var thisTown = towns[townList[i]];
			var tps = towns[townList[i]].mil.units;
			cell1.innerHTML = thisTown.name;
			cell2.innerHTML = thisTown.name;
			cell = row1.insertCell(1);
			cell.innerHTML = (tps.spear.t1.pool + tps.spear.t1.armies) + '</br>' + tps.spear.t1.build;
			tots.spear.t1.pool += (tps.spear.t1.pool + tps.spear.t1.armies);
			tots.spear.t1.build += tps.spear.t1.build;
			cell = row1.insertCell(2);
			cell.innerHTML = (tps.spear.t2.pool + tps.spear.t2.armies) + '</br>' + tps.spear.t2.build;
			tots.spear.t2.pool += (tps.spear.t2.pool + tps.spear.t2.armies);
			tots.spear.t2.build += tps.spear.t2.build;
			cell = row1.insertCell(3);
			cell.innerHTML = (tps.inf.t1.pool + tps.inf.t1.armies) + '</br>' + tps.inf.t1.build;
			tots.inf.t1.pool += (tps.inf.t1.pool + tps.inf.t1.armies);
			tots.inf.t1.build += tps.inf.t1.build;
			cell = row1.insertCell(4);
			cell.innerHTML = (tps.inf.t2.pool + tps.inf.t2.armies) + '</br>' + tps.inf.t2.build;
			tots.inf.t2.pool += (tps.inf.t2.pool + tps.inf.t2.armies);
			tots.inf.t2.build += tps.inf.t2.build;
			cell = row1.insertCell(5);
			cell.innerHTML = (tps.range.t1.pool + tps.range.t1.armies) + '</br>' + tps.range.t1.build;
			tots.range.t1.pool += (tps.range.t1.pool + tps.range.t1.armies);
			tots.range.t1.build += tps.range.t1.build;
			cell = row1.insertCell(6);
			cell.innerHTML = (tps.range.t2.pool + tps.range.t2.armies) + '</br>' + tps.range.t2.build;
			tots.range.t2.pool += (tps.range.t2.pool + tps.range.t2.armies);
			tots.range.t2.build += tps.range.t2.build;
			cell = row1.insertCell(7);
			cell.innerHTML = (tps.cav.t1.pool + tps.cav.t1.armies) + '</br>' + tps.cav.t1.build;
			tots.cav.t1.pool += (tps.cav.t1.pool + tps.cav.t1.armies);
			tots.cav.t1.build += tps.cav.t1.build;
			cell = row1.insertCell(8);
			cell.innerHTML = (tps.cav.t2.pool + tps.cav.t2.armies) + '</br>' + tps.cav.t2.build;
			tots.cav.t2.pool += (tps.cav.t2.pool + tps.cav.t2.armies);
			tots.cav.t2.build += tps.cav.t2.build;
			cell = row1.insertCell(9);
			cell.innerHTML = (tps.siege.t1.pool + tps.siege.t1.armies) + '</br>' + tps.siege.t1.build;
			tots.siege.t1.pool += (tps.siege.t1.pool + tps.siege.t1.armies);
			tots.siege.t1.build += tps.siege.t1.build;
			cell = row1.insertCell(10);
			cell.innerHTML = (tps.siege.t2.pool + tps.siege.t2.armies) + '</br>' + tps.siege.t2.build;
			tots.siege.t2.pool += (tps.siege.t2.pool + tps.siege.t2.armies);
			tots.siege.t2.build += tps.siege.t2.build;
			cell = row2.insertCell(1);
			cell.innerHTML = thisTown.mil.summary.atk;
			cell = row2.insertCell(2);
			cell.innerHTML = thisTown.mil.summary.spearDef;
			cell = row2.insertCell(3);
			cell.innerHTML = thisTown.mil.summary.infDef;
			cell = row2.insertCell(4);
			cell.innerHTML = thisTown.mil.summary.bowDef;
			cell = row2.insertCell(5);
			cell.innerHTML = thisTown.mil.summary.cavDef;
		}
		var row1 = body1.insertRow(-1);
		var cell1 = row1.insertCell(0);
		cell1.innerHTML = "Totals";
		cell = row1.insertCell(1);
		cell.innerHTML = tots.spear.t1.pool + '</br>' + tots.spear.t1.build;
		cell = row1.insertCell(2);
		cell.innerHTML = tots.spear.t2.pool + '</br>' + tots.spear.t2.build;
		cell = row1.insertCell(3);
		cell.innerHTML = tots.inf.t1.pool + '</br>' + tots.inf.t1.build;
		cell = row1.insertCell(4);
		cell.innerHTML = tots.inf.t2.pool + '</br>' + tots.inf.t2.build;
		cell = row1.insertCell(5);
		cell.innerHTML = tots.range.t1.pool + '</br>' + tots.range.t1.build;
		cell = row1.insertCell(6);
		cell.innerHTML = tots.range.t2.pool + '</br>' + tots.range.t2.build;
		cell = row1.insertCell(7);
		cell.innerHTML = tots.cav.t1.pool + '</br>' + tots.cav.t1.build;
		cell = row1.insertCell(8);
		cell.innerHTML = tots.cav.t2.pool + '</br>' + tots.cav.t2.build;
		cell = row1.insertCell(9);
		cell.innerHTML = tots.siege.t1.pool + '</br>' + tots.siege.t1.build;
		cell = row1.insertCell(10);
		cell.innerHTML = tots.siege.t2.pool + '</br>' + tots.siege.t2.build;
		var rubbish = '';
//		dt.outputArea.setAttribute('class', 'see');
		dt.showTool("#troopSummHtml");

	},
	/* Function: scanMilOverview
	 * Gather troop information from the Military Overview page.
	 * The data is all contained in fieldsets and the legend of the fieldset defines 
	 * what type of info is in there.
	 */
	scanMilOverview: function () {
		try {
			var msg = "Scanning Military Overview.";
			dt.logEntry(msg);
			// Clear the troops assigned to armies
			var milUnits = dt[PlayerId].towns[CurrentTown].mil.units;
			milUnits.cav.t1.armies = 0;
			milUnits.cav.t2.armies = 0;
			milUnits.inf.t1.armies = 0;
			milUnits.inf.t2.armies = 0;
			milUnits.spear.t1.armies = 0;
			milUnits.spear.t2.armies = 0;
			milUnits.range.t1.armies = 0;
			milUnits.range.t2.armies = 0;
			milUnits.siege.t1.armies = 0;
			milUnits.siege.t2.armies = 0;
			// Clear the troops being built
			milUnits.cav.t1.build = 0;
			milUnits.cav.t2.build = 0;
			milUnits.inf.t1.build = 0;
			milUnits.inf.t2.build = 0;
			milUnits.spear.t1.build = 0;
			milUnits.spear.t2.build = 0;
			milUnits.range.t1.build = 0;
			milUnits.range.t2.build = 0;
			milUnits.siege.t1.build = 0;
			milUnits.siege.t2.build = 0;
			// Clear the troops in the pool

			milUnits.cav.t1.pool = 0;
			milUnits.cav.t2.pool = 0;
			milUnits.inf.t1.pool = 0;
			milUnits.inf.t2.pool = 0;
			milUnits.spear.t1.pool = 0;
			milUnits.spear.t2.pool = 0;
			milUnits.range.t1.pool = 0;
			milUnits.range.t2.pool = 0;
			milUnits.siege.t1.pool = 0;
			milUnits.siege.t2.pool = 0;
			// Get all the fieldsets
			var fieldsets = document.querySelectorAll("div.info fieldset");
			var numFieldsets = fieldsets.length;
			// Step through the fieldsets
			for (var i = 0; i < numFieldsets; i++) {
				var thisFieldset = fieldsets[i];
				var legendtag = thisFieldset.querySelector("first-child");
				// Identify what type of content this fieldset has by getting the textContent of the first child
				var tc = thisFieldset.children[0].textContent;
				if (tc.indexOf('Commanders') !== -1) {
					var msg = "Processing unassigned commanders.";
					dt.logEntry(msg);

					// Unassigned Commanders
					// Get the rows in the table of unassigned commanders
					var rows = thisFieldset.querySelectorAll('tr');
					var numrows = rows.length;
					// Process each row (skip row 0 as it is the titles)
					for (var j = 1; j < numrows; j++) {
						var tds = rows[j].querySelectorAll('td');
						if (tds.length !== 1) {
							if (tds[0].querySelector("span") !== null) {
								// Get the id of the unit type
								var uid = tds[0].querySelector("span").getAttribute("data");
//					var uid = t.getAttribute("data");
								// Get the commander id
								var cid = tds[1].querySelector("a").getAttribute("href").split('/')[3];
								// Get the commander name and lvl
								var t = tds[1].querySelector("a").innerHTML.split('(');
								var cName = t[0].trim();
								var cLvl = t[1].trim().substring(1, (t[1].length) - 1);
								// Check to see if this commander is known. If yes then update, if no then add it.
								if (dt[PlayerId].towns[CurrentTown].mil.commanders.hasOwnProperty(cid)) {
									dt[PlayerId].towns[CurrentTown].mil.commanders[cid].name = cName;
									dt[PlayerId].towns[CurrentTown].mil.commanders[cid].lvl = cLvl;
								} else {
									dt[PlayerId].towns[CurrentTown].mil.commanders[cid] = new dt.commander(cName, cLvl, 0, {}, {});
								}
							}
						}
					}
				}
				if (tc.indexOf('Army:') !== -1) {
					var msg = "Processing armies.";
					dt.logEntry(msg);
					// An army
					var rows = thisFieldset.querySelectorAll('tr');
					var numrows = rows.length;
					// Process each row. Have to check every row as there may not be a heading row.
					// There are 3 possible types of row:
					// Title row - No td elements, only th.
					// Commander row - td[1] is non-empty.
					// Unit row - td[1] is empty.
					for (var j = 0; j < numrows; j++) {
						var tds = rows[j].querySelectorAll('td');
						if (tds.length !== 0) {
							// Got td elements so it is not a Header row.
							if (tds[1].textContent !== '') {
								// tds[1] not empty so it is a commander row
								// Get the commander id
								var cid = tds[1].querySelector("a").getAttribute("href").split('/')[3];
								// Get the commander name
								var t = tds[1].querySelector("a").textContent;
								var cName = t.trim();
								// Check to see if this commander is known. If yes then update, if no then add it.
								if (dt[PlayerId].towns[CurrentTown].mil.commanders.hasOwnProperty(cid)) {
									dt[PlayerId].towns[CurrentTown].mil.commanders[cid].name = cName;
								} else {
									dt[PlayerId].towns[CurrentTown].mil.commanders[cid] = new dt.commander(cName, 0, 0, {}, {});
								}

							} else {
								if (tds[2].querySelector("span") !== null) {
									//  tds[1] is empty so a unit row
									var uid = tds[2].querySelector("span").getAttribute("data");
									var lvlType = dt.military.procUid(uid);
									var present = parseInt((tds[4].innerHTML).replace(',', ''));
									dt[PlayerId].towns[CurrentTown].mil.units[lvlType[1]][lvlType[0]].armies += parseInt(present);
								}
							}
						}

					}
				}
				if (tc.indexOf('Unit Pool') !== -1) {
					var msg = "Processing unit pool.";
					dt.logEntry(msg);
					// If i = 1 then this is the main pool that we get the build figures from otherwise ignore it.
					if (i === 1) {
						// Get the rows in the table of unassigned/build troops
						var rows = thisFieldset.querySelectorAll('tr');
						// Process each row (skip row 0 as it is the titles)
						var numrows = rows.length;
						for (var j = 1; j < numrows; j++) {
							var tds = rows[j].querySelectorAll('td');
							if (tds[0].querySelector("span") !== null) {
								// Get the id of the unit type
								var uid = tds[0].querySelector("span").getAttribute("data");
								var present = tds[1].innerHTML;
								var build = tds[3].innerHTML;
								var lvlType = dt.military.procUid(uid);
								dt[PlayerId].towns[CurrentTown].mil.units[lvlType[1]][lvlType[0]].pool = parseInt(present);
								dt[PlayerId].towns[CurrentTown].mil.units[lvlType[1]][lvlType[0]].build = parseInt(build);
							}
						}
					}
				}
				// Overall attack/defence values for this town
				if (tc.indexOf('TOTALS') !== -1) {
					var msg = "Processing attack/defence values for town.";
					dt.logEntry(msg);
					var rows = thisFieldset.querySelectorAll('tr');
					// Process each row (skip row 0 as it is the titles)
					var numrows = rows.length;
					for (var j = 1; j < numrows; j++) {
						var tds = rows[j].querySelectorAll('td');
						dt[PlayerId].towns[CurrentTown].mil.summary.atk = tds.item(4).textContent;
						dt[PlayerId].towns[CurrentTown].mil.summary.spearDef = tds.item(5).textContent;
						dt[PlayerId].towns[CurrentTown].mil.summary.bowDef = tds.item(6).textContent;
						dt[PlayerId].towns[CurrentTown].mil.summary.infDef = tds.item(7).textContent;
						dt[PlayerId].towns[CurrentTown].mil.summary.cavDef = tds.item(8).textContent;
						var key = CurrentTown + ':mil';
						locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].mil));
					}
				}
			}
			var key = CurrentTown + ':mil';
			locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].mil));
			var msg = "Military Overview scan finished.";
			dt.logEntry(msg);
			console.log("Mil Overview scanned...");
		}
		catch (e) {
//			console.log("error in call to inventory gathering at the end of hashChanged...");
			console.log("debug: " + e.message);
			var rubbish = '';
		}
	},
	/* Method: scanMilMov
	 * Scan the military movement page
	 */
	scanMilMov: function () {
		var msg = "Military Movement scan - not available.";
		dt.logEntry(msg);
	},
	/* Method: scanSieges
	 * Scan the military movement page
	 */
	scanSieges: function () {
		var msg = "Siege scan - not available.";
		dt.logEntry(msg);
	},
	/* Method: scanMilArmy
	 * Scan the Military Armies page
	 */
	scanMilArmy: function () {
		var msg = "Military Army scan - not available.";
		dt.logEntry(msg);
	},
	/* Method: scanMilCommander
	 * Scan the Military Commander page
	 */
	scanMilCommander: function () {
		var msg = "Scanning Military Commanders.";
		dt.logEntry(msg);

// Get the divs that hold all the info for commanders in this town
		var cmdrDivs = document.querySelectorAll("div.ui-accordion-content.ui-helper-reset.ui-widget-content.ui-corner-bottom");
		var rubbish = '';
// Step through the returned divs
		for (i = 0; i < cmdrDivs.length; i++) {
			var currentCmdrDiv = cmdrDivs[i];
			var equipDiv = cmdrDivs[i].querySelector('div div div');
			// currentcmdrDiv div div form.odd input.hidden
			var cmdrId = currentCmdrDiv.querySelector('div div form.odd input.hidden').value;
//			if(!dt[PlayerId].towns[CurrentTown].mil.commanders.hasOwnProperty(cmdrId)){
			// (name, lvl, xp, self, div, uType)
			var hdr = currentCmdrDiv.parentElement.querySelectorAll("h3").item(i);
			var cTds = hdr.querySelectorAll("td");
			var cName = cTds.item(1).textContent;
			var cLvl = cTds.item(5).textContent;
			var cXp = cTds.item(4).textContent.split('/')[0];
			dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId] = new dt.military.commander(cName, cLvl, cXp, {}, {}, '');
//			}
			dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self = {
				atk: 0,
				spDef: 0,
				rgDef: 0,
				infDef: 0,
				cavDef: 0,
				cbtSurv: 0,
				health: 0,
				heal: 1,
				escAssas: 0
			};
			dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div = {spAtk: 0, rgAtk: 0, infAtk: 0, cavAtk: 0, spDef: 0, rgDef: 0, infDef: 0, cavDef: 0, move: 0, carry: 0, magic: 0};
//			/html/body/div[1]/div[2]/table/tbody/tr[1]/td[1]/div/div/div/div[2]/div[1]/div[1]/div/div[1]/div[1]
// <div style="font-size: 15px;font-weight: bold;">Level 13 Longbowman</div>
			var cType = currentCmdrDiv.querySelector("div > div > div > div > div").textContent.split(' ')[2].split('\n')[0];
			dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].cType = cType;
			var tds = currentCmdrDiv.querySelectorAll('div div fieldset table td');
			for (j = 1; j < tds.length; j = j + 1) {
				var thisTd = tds[j];
				if (thisTd.childElementCount > 1) {
					var skillName = thisTd.querySelector('div.skillName').textContent;
					var skillTxt = thisTd.querySelector('div.skillBarTxt').textContent;
					var skillArray = skillTxt.split('/');
					skillArray[0] = parseInt(skillArray[0]);
					switch (skillName) {
						case 'Heroism':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self.atk = skillArray[0];
							break;
						case 'Defy Death':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self.cbtSurv = skillArray[0];
							break;
						case 'Break Spear Wall':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self.spDef = skillArray[0];
							break;
						case 'Cover':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self.rgDef = skillArray[0];
							break;
						case 'Sword Mastery':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self.infDef = skillArray[0];
							break;
						case 'Avoid Charge':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self.cavDef = skillArray[0];
							break;
						case 'Vitality':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self.health = skillArray[0];
							break;
							// Accelerated Healing
						case 'Accelerated Healing':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self.heal = skillArray[0];
							break;
						case 'Uncanny Sense':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].self.escAssas = skillArray[0];
							break;
						case 'Close Quarter Penetration':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.spAtk = skillArray[0];
							break;
						case 'Agile Defence':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.spDef = skillArray[0];
							break;
						case 'Forced March':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.move = skillArray[0];
							break;
						case 'Concentrated Fire':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.rgAtk = skillArray[0];
							break;
						case 'Tortoise Formation':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.rgDef = skillArray[0];
							break;
						case 'Military Logistics':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.carry = skillArray[0];
							break;
						case 'Bloodlust':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.infAtk = skillArray[0];
							break;
						case 'Interlocked Shields':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.infDef = skillArray[0];
							break;
						case 'Force Of Will':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.magic = skillArray[0];
							break;
						case 'Charge':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.cavAtk = skillArray[0];
							break;
						case 'Square Formation':
							dt[PlayerId].towns[CurrentTown].mil.commanders[cmdrId].div.cavDef = skillArray[0];
							break;
					}
				}
			}
			var key = CurrentTown + ':mil';
			locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].mil));
		}
		var msg = "Military Commanders scan finished.";
		dt.logEntry(msg);
//	}
	},
	/* Function: procUid
	 * Process a uid to get a unit type and level
	 * 
	 * Parameter:
	 * uid - string. The unit id in the format i=5|72
	 * 
	 * Returns: array. The level and type in an array [uLvl, uType]
	 */
	procUid: function (uid) {
		bits = uid.split('|');
		var unitId = parseInt(bits[1]);
		// Level
		if (dt.unitLvls.t1.indexOf(unitId) > -1) {
			var uLvl = 't1';
		} else {
			var uLvl = 't2';
		}
		// Type
		if (dt.unitTypes.spear.indexOf(unitId) > -1) {
			var uType = 'spear';
		}
		if (dt.unitTypes.inf.indexOf(unitId) > -1) {
			var uType = 'inf';
		}
		if (dt.unitTypes.bow.indexOf(unitId) > -1) {
			var uType = 'range';
		}
		if (dt.unitTypes.cav.indexOf(unitId) > -1) {
			var uType = 'cav';
		}
		if (dt.unitTypes.siege.indexOf(unitId) > -1) {
			var uType = 'siege';
		}
		return [uLvl, uType];
	},
};