/* File: production.js
 * Functions to manage production queues and alerts
 */
dt.production = {
	/* Method: setup
	 * Setup the production monitoring
	 */
	setup: function () {
//var topNav = document.querySelector('body');
//dt.prodAlarm = dt.addElement('',topNav,'img',['src','alt','id','class'],[dt.server + '/images/prodAlert.gif','Prod queue ended','dt_prodAlarm','nosee']);
//	this.updateQueues();

	},
	/* Method: monitorSetup
	 * Setup which production buildings in a town to monitor
	 */
	monitorSetup: function () {
		var twnBldgs = Object.keys(dt[PlayerId].towns[CurrentTown].prod);
		dt.removeRows(document.querySelector('#bldgsToMon'))
		var bldgsToMon = document.querySelector('#bldgsToMon tbody');
		for (var i = 0; i < twnBldgs.length; i++) {
			var bldgId = twnBldgs[i];
			var row = bldgsToMon.insertRow(-1);
			var cell = row.insertCell(0);
			// <input type="checkbox" name="filters[]" value="1" />Arctic<br />
			dt.addElement2(cell, 'input', ['type', 'name', 'value', 'onchange'], ['checkbox', 'filters[]', bldgId, 'dt.production.changeEventHandler(event)']);
			var cBox = cell.querySelector('input');
			cBox.checked = dt[PlayerId].towns[CurrentTown].prod[bldgId].alertStatus;
			cell = row.insertCell(1);
			cell.textContent = dt[PlayerId].towns[CurrentTown].prod[bldgId].Building;
		}
		dt.showTool("#prodMonSetupHtml");
	},
	/* Method: monitorSetupDone
	 * 
	 */
	monitorSetupDone: function () {
		document.getElementById("dt_input").innerHTML = "";
	},
	/* Method: changeEventHandler
	 * 
	 */
	changeEventHandler: function (event) {
		var bldg = event.target.value;
		if (dt[PlayerId].towns[CurrentTown].prod[bldg].alertStatus === false) {
			dt[PlayerId].towns[CurrentTown].prod[bldg].alertStatus = true;
		} else {
			dt[PlayerId].towns[CurrentTown].prod[bldg].alertStatus = false;
		}
		var key = CurrentTown + ':prod';
		locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].prod));

		var rubbish = '';
	},
	/* Method: showIdle
	 * Show the production buildings in all towns that are set to be monitored and are idle.
	 */
	showIdle: function () {
		dt.showTool('#showIdleBldgsHtml');
		// Turn of the visual alert
		var alarmImg = document.getElementById('dt_prodAlarm');
		alarmImg.setAttribute('class', 'nosee');
		dt.removeRows(document.querySelector("#idleQueuesTbl"));
		// Get the tbody of the table for the idle queues
		var tb = document.querySelector('#idleQueuesTbl tbody');
		// Get the list of towns
		var twns = dt[PlayerId].towns.list;
		// Step through the towns
		for (var t = 0; t < twns.length; t++) {
			// Get the list of monitored buildings for this town
			var thisTownProdBldgs = Object.keys(dt[PlayerId].towns[twns[t]].prod);
			// Loop through each of these buildings
			for (var i = 0; i < thisTownProdBldgs.length; i++) {
				var bldgId = thisTownProdBldgs[i];
				// Check if this building queue is empty and is set to be monitored.
				if (dt[PlayerId].towns[twns[t]].prod[bldgId].endsAt === "Empty" && dt[PlayerId].towns[twns[t]].prod[bldgId].alertStatus === true) {
					// Yes it is so add it to the table
					var row = tb.insertRow(-1);
					var cell = row.insertCell(0);
					cell.textContent = dt[PlayerId].towns[twns[t]].name;
					cell = row.insertCell(1);
					cell.textContent = dt[PlayerId].towns[twns[t]].prod[bldgId].Building;
				}
			}
		}
		dt.showTool("#showIdleBldgsHtml");
	},
	/* Method: getProdSchedule
	 * Set up a check if the page has loaded
	 */
	getProdSchedule: function () {
		dt.pageLoadedCheck = window.setInterval(this.schedPageReady, 500);
	},
	/* Method: schedPageReady
	 * Capture the production schedule for a town
	 */
	schedPageReady: function () {
		var checkInfos = document.querySelector("div.info fieldset div tr.odd");
		try {
			if (checkInfos.querySelector("td").querySelector("span")) {
				// Page has loaded so clear the repeat calling
				clearInterval(dt.pageLoadedCheck);
				var msg = "Scanning production queue.";
				dt.logEntry(msg);
				var tmp = dt[PlayerId].towns[CurrentTown].prod;
				dt[PlayerId].towns[CurrentTown].prod = {};
				var parent = document.querySelector("div.info");
				var fieldsets = parent.querySelectorAll("fieldset");
				var numFieldsets = fieldsets.length;
				for (var i = 0; i < numFieldsets; i++) {
					var thisFieldset = fieldsets[i];
					// Process the legend to get the id of the building and the level
					var legendtag = thisFieldset.querySelector("legend");
					var bLink = legendtag.querySelector("a").getAttribute("href");
					var bId = bLink.split('/')[3];
					var bName = legendtag.querySelector("span a").textContent.split('-')[0];
					dt[PlayerId].towns[CurrentTown].prod[bId] = {'Building': bName, item: '', endsAt: '', alertStatus: false};
					// Get the table rows holding the queued items for this building
					var rows = thisFieldset.querySelectorAll('tr');
					// Skip straight to the last row as this is the one with the latest completion time.
					var numrows = rows.length;
					if (numrows > 0) {
						// Get the td elements in this row
						var tds = rows[numrows - 1].querySelectorAll('td');
						// Get the id of the item
						var iId = tds[0].querySelector("span").getAttribute("data");
						// Get the name of the item
						var iName = tds[1].textContent;
						dt[PlayerId].towns[CurrentTown].prod[bId].item = iName;
						// Get the completion time
						var compTime = tds[6].textContent;
						dt[PlayerId].towns[CurrentTown].prod[bId].endsAt = compTime;
					} else {
						dt[PlayerId].towns[CurrentTown].prod[bId].item = '';
						dt[PlayerId].towns[CurrentTown].prod[bId].endsAt = 'Empty';
					}
					try {
						if (tmp[bId].hasOwnProperty('alertStatus')) {
							dt[PlayerId].towns[CurrentTown].prod[bId].alertStatus = tmp[bId].alertStatus;
						} else {
							dt[PlayerId].towns[CurrentTown].prod[bId].alertStatus = false;
						}
					}
					catch (e) {
						dt[PlayerId].towns[CurrentTown].prod[bId].alertStatus = false;
					}
				}
				var key = CurrentTown + ':prod';
				locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].prod));
				var msg = "Production queue scan finished.";
				dt.logEntry(msg);
			}
			dt.invent.getTownInventory();
		}
		catch (e) {
			console.log("debug: " + e.message);
		}
	},
	/* Method: getBldgProd
	 * Set up a check if the page has loaded
	 */
	getBldgProd: function (bId) {
		dt.bldgProdLoadedCheck = window.setInterval(this.bldgProdPageReady, 500,bId);
	},
	/* Method: bldgProdPageReady
	 * Get production queue information from a building resource production screen
	 */
	bldgProdPageReady: function (bId) {
//		console.log(dt.bldgProdLoadedCheck+" bldgProdPageReady: "+bId);
		// Check if the page has fully loaded
		try {
			if (document.querySelectorAll('#MainContentDiv div > h3').item(1).textContent == "Production Schedule") {
				clearInterval(dt.bldgProdLoadedCheck);
				console.log("Processing bldg production queue..."+bId);		
				var infoDivs = document.querySelectorAll('div.info');
				// Page has loaded so clear the repeat calling
				if (infoDivs.length > 1) {
					// More than one so there is at least one item being produced.
					// Get the id of the building
					var bId = window.location.hash.split('/')[3];
					// Get the monitor status then clear the production info for this building
					var monStatus = dt[PlayerId].towns[CurrentTown].prod[bId].alertStatus;
					dt[PlayerId].towns[CurrentTown].prod[bId] = {};
					// Get the table holding the production info
//			var tmp = infoDivs.length;
					var prodTbl = infoDivs[infoDivs.length - 1];
					var bName = document.querySelector('h2').textContent;
					var rows = prodTbl.querySelectorAll('tr');
					var lRow = rows[rows.length - 1];
					var tds = lRow.querySelectorAll('td');
					var iName = tds[1].textContent;
					dt[PlayerId].towns[CurrentTown].prod[bId] = {'Building': bName, item: '', endsAt: '', alertStatus: monStatus};
					dt[PlayerId].towns[CurrentTown].prod[bId].item = iName;
					// Get the completion time
					var compTime = tds[6].textContent;
					dt[PlayerId].towns[CurrentTown].prod[bId].endsAt = compTime;
					var key = CurrentTown + ':prod';
					locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].prod));

					var rubbish = '';
				}
//		dt.mutations.setup();
			}
		}
		catch (e) {
			console.log("debug: " + e.message);
		}

	},
};

