// #tree
/* 
 * Module by Ryan Morr that creates a permanent mutation observer to monitor for
 * the existence of a given element.
 * http://ryanmorr.com/using-mutation-observers-to-watch-for-element-availability/
 */
(function (win) {
	'use strict';

	var listeners = [],
			  doc = win.document,
			  MutationObserver = win.MutationObserver || win.WebKitMutationObserver,
			  observer;

	function ready(selector, fn) {
		// Store the selector and callback to be monitored
		listeners.push({
			selector: selector,
			fn: fn
		});
		if (!observer) {
			// Watch for changes in the document
			observer = new MutationObserver(check);
			observer.observe(doc.documentElement, {
				childList: true,
				subtree: true
			});
		}
		// Check if the element is currently in the DOM
		check();
	}

	function check() {
		// Check the DOM for elements matching a stored selector
		for (var i = 0, len = listeners.length, listener, elements; i < len; i++) {
			listener = listeners[i];
			// Query for elements matching the specified selector
			elements = doc.querySelectorAll(listener.selector);
			for (var j = 0, jLen = elements.length, element; j < jLen; j++) {
				element = elements[j];
				// Make sure the callback isn't invoked with the 
				// same element more than once
				if (!element.ready) {
					element.ready = true;
					// Invoke the callback with the element
					listener.fn.call(element, element);
				}
			}
		}
	}

	// Expose `ready`
	win.ready = ready;

})(this);

ans = {};
ans.pages = ["#/Trade/HubOrders", "#/Trade/Orders","#/Trade/Markets"];
ans.namechange = function () {
	try{
//	var hashParts = location.hash.split("?")[0];
//	if (ans.pages.includes(hashParts)) {
		// Get all the li elements that are children of the Anatomies tree
		var anatomies = document.querySelectorAll("#tree > ul li.jstree-leaf");
		for (var i = 0; i < anatomies.length; ++i) {
			var item = anatomies[i];  // Calling myNodeList.item(i) isn't necessary in JavaScript
			var aTag = item.querySelector("a").innerHTML;
			aTag = this.strReplace(aTag,"Exoskeleton", "EXO");
			aTag = this.strReplace(aTag,"Giant", "GT");
			aTag = this.strReplace(aTag,"Poisonous", "PSNS");
			item.querySelector("a").innerHTML = aTag;
		}
	}
	catch(e){
		
	}
//	}
};
ans.strReplace = function(source,oldval,newval){
	return source.split(oldval).join(newval);
};
window.onhashchange = ans.namechange;
ready("#tree li.jstree-last", function (element) {
	var hashParts = location.hash.split("?")[0];
	if (ans.pages.includes(hashParts)) {
		ans.namechange();
	}
});

